Generate the autocompletion script for ko for the specified shell.
See each sub-command's help for details on how to use the generated script.

Usage:
  ko completion [command]

Available Commands:
  bash        Generate the autocompletion script for bash
  fish        Generate the autocompletion script for fish
  powershell  Generate the autocompletion script for powershell
  zsh         Generate the autocompletion script for zsh

Flags:
  -h, --help   help for completion

Global Flags:
  -v, --verbose   Enable debug logs

Use "ko completion [command] --help" for more information about a command.
